@@ -892,28 +892,6 @@ validation exception on failure, but this could not be proved.
     end
   end
 
-  context 'against a pre-set password in a model that has_secure_password' do
-    if Shoulda::Matchers::RailsShim.active_model_st_6_1?
-      it 'raises a CouldNotSetPasswordError' do
-        user_class = define_model :user, password_digest: :string do
-          has_secure_password validations: false
-          validates_presence_of :password
-        end
-
-        user = user_class.new
-        user.password = 'something'
-
-        assertion = lambda do
-          expect(user).to validate_presence_of(:password)
-        end
-
-        expect(&assertion).to raise_error(
-          Shoulda::Matchers::ActiveModel::CouldNotSetPasswordError,
-        )
-      end
-    end
-  end
-
   context 'when the attribute typecasts nil to another blank value, such as an empty array' do
     it 'accepts (and does not raise an AttributeChangedValueError)' do
       model = define_active_model_class :example, accessors: [:foo] do
